@@ -1,5 +1,4 @@
 //! Debhelper utilities.
-use debian_control::lossless::relations::Relations;
 use debversion::Version;
 use std::path::Path;
 
@@ -219,7 +218,7 @@ pub fn ensure_minimum_debhelper_version(
         }
     }
 
-    let mut rels = source.build_depends().unwrap_or_else(Relations::new);
+    let mut rels = source.build_depends().unwrap_or_default();
 
     // Check if debhelper-compat is present
     for entry in rels.entries() {
@@ -280,7 +279,7 @@ pub fn ensure_minimum_debhelper_version(
 /// assert_eq!(sequences, vec!["python3", "nodejs"]);
 /// ```
 pub fn get_sequences(source: &debian_control::lossless::Source) -> impl Iterator<Item = String> {
-    let build_depends = source.build_depends().unwrap_or_else(Relations::new);
+    let build_depends = source.build_depends().unwrap_or_default();
 
     build_depends
         .entries()
@@ -355,7 +354,7 @@ Build-Depends: debhelper
         #[test]
         fn test_already() {
             let text = "Source: foo\nBuild-Depends: debhelper (>= 10)\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
@@ -378,7 +377,7 @@ Build-Depends: debhelper
         #[test]
         fn test_already_compat() {
             let text = "Source: foo\nBuild-Depends: debhelper-compat (= 10)\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
@@ -401,7 +400,7 @@ Build-Depends: debhelper
         #[test]
         fn test_bump() {
             let text = "Source: foo\nBuild-Depends: debhelper (>= 10)\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
@@ -416,7 +415,7 @@ Build-Depends: debhelper
         #[test]
         fn test_bump_compat() {
             let text = "Source: foo\nBuild-Depends: debhelper-compat (= 10)\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
@@ -439,7 +438,7 @@ Build-Depends: debhelper
         #[test]
         fn test_not_set() {
             let text = "Source: foo\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
@@ -454,7 +453,7 @@ Build-Depends: debhelper
         #[test]
         fn test_in_indep() {
             let text = "Source: foo\nBuild-Depends-Indep: debhelper (>= 9)\n";
-            let mut control = debian_control::Control::read_relaxed(text.as_bytes())
+            let control = debian_control::Control::read_relaxed(text.as_bytes())
                 .unwrap()
                 .0;
             let mut source = control.source().unwrap();
